@@ -17,35 +17,6 @@ def just(item):
     yield item
 
 
-def range_from_text(text_range):
-    """A range of integers from a textual description.
-
-    Args:
-        text_range: A string of the form "<first>-<last>" such as "7-10" describing the inclusive
-            ends of a range of integers.
-
-    Returns:
-        A range object.
-    """
-    first, separator, last = text_range.partition("-")
-    start = int(first)
-    last = int(last)
-    stop = last + 1 if separator else start + 1
-    if stop < start:
-        raise ValueError(f"Textual range {text_range} has start {start} after last {last}")
-    return range(start, stop)
-
-
-def expand_numbered_list(indexes):
-    """Expands a string containing numbered items into a list of integers.
-
-    e.g. "1, 2, 5, 7-10, 15, 20-25" -> [1, 2, 5, 7, 8, 9, 10, 15, 20, 21, 22, 23, 24, 25]
-    """
-    text_ranges = indexes.split(",")
-    ranges = map(range_from_text, text_ranges)
-    return list(itertools.chain.from_iterable(ranges))
-
-
 def generate(collection=None):
 
     if collection is None:
